# A description of what this class does
#
# @summary A short summary of the purpose of this class
#
# @example
#   include workstation
class workstation (
  String[1] $user = $facts['primary_user'],
  Enum['bash', 'zsh', 'fish'] $shell = 'bash',
  Optional[String[1]] $github_token = undef,
  Optional[Array[Hash]] $dotfiles = undef,
  Optional[Hash] $repos = undef,
) {

  if $user == 'root' {
    fail('Workstation module user cannot be root!')
  }

  $home = $facts['os']['family'] ? {
    'Darwin' => "/Users/${user}",
    default  => "/home/${user}",
  }

  case $facts['os']['family'] {
    'Darwin': { include workstation::mac }
    'Debian': { notify {'There are no Debian-only classes at this time.':} }
    default:  { fail("Unsupported platform: ${facts['os']['family']}") }
  }

  $shell_path = $shell ? {
    'bash' => '/bin/bash',
    'zsh'  => '/bin/zsh',
    'fish' => '/usr/local/bin/fish',
  }

  $require_pkg = $shell ? {
    'bash'  => undef,
    'zsh'   => 'zsh',
    'fish'  => 'fish',
  }

  user { $user:
    shell   => $shell_path,
    home    => $home,
    require => Package[$require_pkg],
  }

}
